==> bouncycastle_1.39.orig.tar.gz: bouncycastle-1.39.orig/jdk1.3/org/bouncycastle/cms/RecipientId.java <==
package org.bouncycastle.cms;

import org.bouncycastle.jce.cert.X509CertSelector;
import java.util.Arrays;

public class RecipientId
    extends X509CertSelector
{
    byte[]  keyIdentifier = null;

    /**
     * set a secret key identifier (for use with KEKRecipientInfo)
     */
    public void setKeyIdentifier(
        byte[]  keyIdentifier)
    {
        this.keyIdentifier = keyIdentifier;
    }

    /**
     * return the secret key identifier
     */
    public byte[] getKeyIdentifier()
    {
        return keyIdentifier;
    }

    public int hashCode()
    {
        int     code = 0;

        if (keyIdentifier != null)
        {
            for (int i = 0; i != keyIdentifier.length; i++)
            {
                code ^= ((keyIdentifier[i] & 0xff) << (i % 4));
            }
        }

        byte[]  subKeyId = this.getSubjectKeyIdentifier();

        if (subKeyId != null)
        {
            for (int i = 0; i != subKeyId.length; i++)
            {
                code ^= ((subKeyId[i] & 0xff) << (i % 4));
            }
        }

        if (this.getSerialNumber() != null)
        {
            code ^= this.getSerialNumber().hashCode();
        }

        if (this.getIssuerAsString() != null)
        {
            code ^= this.getIssuerAsString().hashCode();
        }

        return code;
    }

    public boolean equals(
        Object  o)
    {
        if (!(o instanceof RecipientId))
        {
            return false;
        }

        RecipientId id = (RecipientId)o;

        return equalsByteArray(keyIdentifier, id.keyIdentifier)
            && equalsByteArray(this.getSubjectKeyIdentifier(), id.getSubjectKeyIdentifier())
            && equalsObj(this.getSerialNumber(), id.getSerialNumber())
            && equalsObj(this.getIssuerAsString(), id.getIssuerAsString());
    }

    private boolean equalsObj(Object a, Object b)
    {
        return (a != null) ? a.equals(b) : b == null;
    }

    private boolean equalsByteArray(byte[] a, byte[] b)
    {
        if (a != null)
        {
            return (b != null) && Arrays.equals(a, b);
        }

        return (b == null);
    }
}

==> bouncycastle_1.44+dfsg.orig.tar.gz: bouncycastle-1.44.orig/jdk1.3/org/bouncycastle/cms/RecipientId.java <==
package org.bouncycastle.cms;

import org.bouncycastle.util.Arrays;

import java.math.BigInteger;
import org.bouncycastle.jce.cert.X509CertSelector;

public class RecipientId
    extends X509CertSelector
{
    byte[]  keyIdentifier = null;

    /**
     * set a secret key identifier (for use with KEKRecipientInfo)
     */
    public void setKeyIdentifier(
        byte[]  keyIdentifier)
    {
        this.keyIdentifier = keyIdentifier;
    }

    /**
     * return the secret key identifier
     */
    public byte[] getKeyIdentifier()
    {
        return keyIdentifier;
    }

    public int hashCode()
    {
        int code = Arrays.hashCode(keyIdentifier)
            ^ Arrays.hashCode(this.getSubjectKeyIdentifier());

        BigInteger serialNumber = this.getSerialNumber();
        if (serialNumber != null)
        {
            code ^= serialNumber.hashCode();
        }

        String issuer = this.getIssuerAsString();
        if (issuer != null)
        {
            code ^= issuer.hashCode();
        }

        return code;
    }

    public boolean equals(
        Object  o)
    {
        if (!(o instanceof RecipientId))
        {
            return false;
        }

        RecipientId id = (RecipientId)o;

        return Arrays.areEqual(keyIdentifier, id.keyIdentifier)
            && Arrays.areEqual(this.getSubjectKeyIdentifier(), id.getSubjectKeyIdentifier())
            && equalsObj(this.getSerialNumber(), id.getSerialNumber())
            && equalsObj(this.getIssuerAsString(), id.getIssuerAsString());
    }

    private boolean equalsObj(Object a, Object b)
    {
        return (a != null) ? a.equals(b) : b == null;
    }
}
